/*
 * kern_feature.h - Kernel-version dependent features definition for NILFS
 *
 * Copyright (C) 2005 Nippon Telegraph and Telephone Corporation.
 *
 * This file is part of NILFS.
 *
 * NILFS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * NILFS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NILFS; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * kern_feature.h,v 1.3 2006/01/17 04:24:26 kihara Exp
 */

#ifndef NILFS_KERN_FEATURE_H
#define NILFS_KERN_FEATURE_H

#include <linux/version.h>

/*
 * Please define as 0/1 here if you want to override
 */

/*
 * defaults dependent to kernel versions
 */

#ifdef LINUX_VERSION_CODE
/*
 * typedef gfp_t included since linux-2.6.15
 */
#ifndef NEED_GFP_T
# define NEED_GFP_T					\
	(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,15))
#endif
/*
 * truncate_inode_pages() should be called in each fs since linux-2.6.14.
 */
#ifndef NEED_TRUNCATE_INODE_PAGES
# define NEED_TRUNCATE_INODE_PAGES			\
	(LINUX_VERSION_CODE > KERNEL_VERSION(2,6,13))
#endif
/*
 * refrigerator() have no arguments since linux-2.6.13.
 */
#ifndef NEED_REFRIGERATOR_ARGS
# define NEED_REFRIGERATOR_ARGS				\
	(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13))
#endif
/*
 * r/w spinlock is used for standard radix-tree since linux-2.6.12.
 */
#ifndef NEED_RWLOCK_FOR_PAGECACHE_LOCK
# define NEED_RWLOCK_FOR_PAGECACHE_LOCK			\
	(LINUX_VERSION_CODE > KERNEL_VERSION(2,6,11))
#endif
/*
 * atomic counter no longer used for truncate_count since linux-2.6.11.
 */
#ifndef NEED_ATOMIC_COUNTER_FOR_TRUNCATE_COUNT
# define NEED_ATOMIC_COUNTER_FOR_TRUNCATE_COUNT		\
	(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11))
#endif
/*
 * MS_ONE_SECOND mount flag deleted since linux-2.6.11.
 */
#ifndef NEED_MS_ONE_SECOND
# define NEED_MS_ONE_SECOND				\
	(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11))
#endif
/*
 * write_inode_now() has return val since linux-2.6.11
 */
#ifndef NEED_VOID_WRITE_INODE_NOW
# define NEED_VOID_WRITE_INODE_NOW			\
	(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11))
#endif

#endif /* LINUX_VERSION_CODE */
#endif /* NILFS_KERN_FEATURE_H */

/*
 * definitions dependent to above macros
 */
#if NEED_GFP_T
#define gfp_t int
#define GFP_T unsigned int
#else
#define GFP_T gfp_t
#endif

/* Local Variables:	*/
/* eval: (c-set-style "linux")	*/
/* End:			*/
